@@ -22,6 +22,8 @@ caching, such as between runs of the browser."}
     {imagecachesize imageCacheSize 10 {Max Images Cached in Memory}
 "This limits the number of images saved in main memory.
 A setting of 0 minimizes memory use."}
+    {window(imageEnable) imageEnable ON {Enable display of in-line images}
+"Use this to enable or disable images in your HTML messages."}
 }
     HtmlInitVars
 }
@@ -183,6 +185,7 @@ proc Html_MimeShow {win part} {
 	    $win insert insert "Showing frames in external viewer\n"
 	    URI_StartViewer $var(S_url)
 	} else {
+	    $win config -wrap word
 	    Html_DisplayInline $win $var(S_url) $html
 	}
     }
@@ -195,6 +198,7 @@ proc Html_Stop {win} {
     Head_ResetColors $win	;# reset window
     Head_Reset $win		;# clear memory
     $win configure -tabs {}
+    $win config -wrap [option get $win wrap Text]
 }
 proc HtmlHit {win x y} {
     upvar #0 HM$win var
@@ -217,7 +221,7 @@ proc Html_DisplayInline {win url html} {
     HMset_state $win -update 10		;# Frequent updates during 1st display
     HMparse_html $html [list HMrender $win]
     Feedback $win ready
-    $win config -cursor xterm
+    $win config -cursor [option get $win cursor Text]
 }
 
 proc HtmlOpen {win} {
