@@ -6,6 +6,12 @@
 # 
 
 # $Log: pgpExec.tcl,v $
+# Revision 1.14  2000/06/16 18:16:26  valdis
+# Various PGP fixes...
+#
+# Revision 1.13  2000/06/15 17:03:11  valdis
+# Add X-Mailer: change, fix PGP Comment: line...
+#
 # Revision 1.12  2000/04/18 18:38:33  valdis
 # Fix quote character to use ascii rather than iso8859-ish one
 #
@@ -154,7 +160,7 @@ proc Pgp_Exec { v exectype arglist outvar {privatekey {}} {interactive 0} } {
 
 # batch mode
 proc Pgp_Exec_Batch { v exectype arglist outvar {password {}} } {
-    global pgp
+    global pgp exmh
     upvar $outvar output
 
     Exmh_Debug "Pgp_Exec_Batch $v $exectype $arglist $outvar \(password\)"
@@ -755,7 +761,7 @@ proc Pgp_Exec_Init {} {
             if {![file exists [set pgp($v,secring)]]} {
                 set pgp($v,secring) {}
             }
-            set pgp($v,privatekeys) [Pgp_Exec_KeyList $v "" Sec]
+            set pgp($v,privatekeys) [Pgp_Exec_KeyList $v $pgp($v,ownPattern) Sec]
             #
             if [info exists pgp($v,config,myname)] {
                 set myname [string tolower [set pgp($v,config,myname)]]
