@@ -411,7 +411,7 @@ proc SeditSendCommon { draft t {post 0} } {
     if {$sedit(autoSign) && ($sedit($t,sigfile) != "") &&
 	([string compare $exmh($id,action) "dist"] != 0)} {
 	set b .sedit${id}.but
-	set cmd [option get $b.sign command {}]
+	set cmd [subst [option get $b.sign command {}]]
 	if {[string length $cmd] == 0} {
 	    Exmh_Debug SeditSend null cmd for $b.sign
 	    set cmd {SeditSign $draft $t}
@@ -545,7 +545,7 @@ proc SeditSave { draft t {hook {}} {isigw 1} } {
 	    regsub -all -nocase "(^|\n)(x-exmh-isig-(comptype|folder):\[^\n\]*\n)+" $X1 {\1} X1
 	    # No X-Mailer on redistributed messages
 	    if {[string compare $exmh($id,action) dist] != 0} {
-		puts $out "X-Mailer: exmh $exmh(version)"
+		puts $out "X-Mailer: exmh $exmh(version) with $exmh(mh_vers)"
 	    }
 	    # Replace X-Exmh-Isig-* headers if necessary
 	    if {$isigw} {
